TautulliAPILookupService enum

Enumerator to handle all API lookup services available in Tautulli.

Inheritance
Available extensions

Values

THEMOVIEDB → const TautulliAPILookupService
TVMAZE → const TautulliAPILookupService
MUSICBRAINZ → const TautulliAPILookupService
NULL → const TautulliAPILookupService

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?

Available on TautulliAPILookupService, provided by the TautulliAPILookupServiceExtension extension

The actual value/key for the API lookup service in Tautulli.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TautulliAPILookupService>
A constant List of the values in this enum, in order of their declaration.