TautulliFallbackImage enum

Enumerator to handle all fallback images available in Tautulli.

Inheritance
Available extensions

Values

POSTER → const TautulliFallbackImage
COVER → const TautulliFallbackImage
ART → const TautulliFallbackImage
POSTER_LIVE → const TautulliFallbackImage
ART_LIVE → const TautulliFallbackImage
ART_LIVE_FULL → const TautulliFallbackImage
NULL → const TautulliFallbackImage

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?

Available on TautulliFallbackImage, provided by the TautulliFallbackImageExtension extension

The actual value/key for the fallback image in Tautulli.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TautulliFallbackImage>
A constant List of the values in this enum, in order of their declaration.