TautulliNotificationLogOrderColumn enum

Enumerator to handle all notification log order columns used in Tautulli.

Inheritance
Available extensions

Values

TIMESTAMP → const TautulliNotificationLogOrderColumn
NOTIFIER_ID → const TautulliNotificationLogOrderColumn
AGENT_NAME → const TautulliNotificationLogOrderColumn
NOTIFY_ACTION → const TautulliNotificationLogOrderColumn
SUBJECT_TEXT → const TautulliNotificationLogOrderColumn
BODY_TEXT → const TautulliNotificationLogOrderColumn
NULL → const TautulliNotificationLogOrderColumn

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?

Available on TautulliNotificationLogOrderColumn, provided by the TautulliNotificationLogOrderColumnExtension extension

The actual value/key for notification log order column used in Tautulli.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TautulliNotificationLogOrderColumn>
A constant List of the values in this enum, in order of their declaration.