TautulliSessionState enum

Enumerator to handle all session states used in Tautulli.

Inheritance
Available extensions

Values

PLAYING → const TautulliSessionState
PAUSED → const TautulliSessionState
BUFFERING → const TautulliSessionState
NULL → const TautulliSessionState

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?

Available on TautulliSessionState, provided by the TautulliSessionStateExtension extension

The actual value/key for session states used in Tautulli.
no setter

Methods

from(String? state) TautulliSessionState?

Available on TautulliSessionState, provided by the TautulliSessionStateExtension extension

Given a String, will return the correct TautulliSessionState object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TautulliSessionState>
A constant List of the values in this enum, in order of their declaration.