TautulliTranscodeDecision enum

Enumerator to handle all transcode decisions used in Tautulli.

Inheritance
Available extensions

Values

TRANSCODE → const TautulliTranscodeDecision
COPY → const TautulliTranscodeDecision
DIRECT_PLAY → const TautulliTranscodeDecision
BURN → const TautulliTranscodeDecision
NULL → const TautulliTranscodeDecision

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
name String?

Available on TautulliTranscodeDecision, provided by the TautulliTranscodeDecisionExtension extension

Readable version of the transcode decision.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?

Available on TautulliTranscodeDecision, provided by the TautulliTranscodeDecisionExtension extension

The actual value/key for transcode decisions used in Tautulli.
no setter

Methods

from(String? decision) TautulliTranscodeDecision?

Available on TautulliTranscodeDecision, provided by the TautulliTranscodeDecisionExtension extension

Given a String, will return the correct TautulliTranscodeDecision object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TautulliTranscodeDecision>
A constant List of the values in this enum, in order of their declaration.