TautulliUsersOrderColumn enum
Enumerator to handle all user order columns used in Tautulli.
- Inheritance
- Available extensions
Values
- USER_THUMB → const TautulliUsersOrderColumn
- FRIENDLY_NAME → const TautulliUsersOrderColumn
- LAST_SEEN → const TautulliUsersOrderColumn
- IP_ADDRESS → const TautulliUsersOrderColumn
- PLATFORM → const TautulliUsersOrderColumn
- PLAYER → const TautulliUsersOrderColumn
- LAST_PLAYED → const TautulliUsersOrderColumn
- PLAYS → const TautulliUsersOrderColumn
- DURATION → const TautulliUsersOrderColumn
- NULL → const TautulliUsersOrderColumn
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String?
-
Available on TautulliUsersOrderColumn, provided by the TautulliUsersOrderColumnExtension extension
The actual value/key for the users order column used in Tautulli.no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TautulliUsersOrderColumn> - A constant List of the values in this enum, in order of their declaration.