TautulliWatchedStatus enum
Enumerator to handle all watched statuses in Tautulli.
- Inheritance
- Available extensions
Values
- UNWATCHED → const TautulliWatchedStatus
- PARTIALLY_WATCHED → const TautulliWatchedStatus
- WATCHED → const TautulliWatchedStatus
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → double?
-
Available on TautulliWatchedStatus, provided by the TautulliWatchedStatusExtension extension
The actual value/key for the API lookup service in Tautulli.no setter
Methods
-
from(
num? watched) → TautulliWatchedStatus? -
Available on TautulliWatchedStatus, provided by the TautulliWatchedStatusExtension extension
Given a double, will return the correctTautulliWatchedStatusobject. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TautulliWatchedStatus> - A constant List of the values in this enum, in order of their declaration.